@@ -10,7 +10,7 @@ from pathlib import Path
 from openpyxl import load_workbook
 from openpyxl.worksheet.worksheet import Worksheet
 
-from excel import write_excel_for_template
+from simple_export.excel import write_excel_for_template
 from simple_export.utils.util import dynamic_method
 class dynamic_method2(dynamic_method):
     def abc(self, coordinate: str, sheet: Worksheet, pos_mapping: collections.defaultdict, pos: collections.defaultdict ):
